#!/bin/sh
##################################################################
#   5724-E34
#   (c) Copyright IBM Corporation 2008, 2009.
#   All rights reserved.
#
#   The source code for this program is not published or otherwise
#   divested of its trade secrets, irrespective of what has been
#   deposited with the U.S. Copyright Office.
##################################################################

#########################################################################
# Utility functions
#########################################################################

terminate()
{
   case $1 in
      MISSING_VALUE)
          echo "Missing value - you can assign default values in GOSalesConfig.sh" ;;

      EDIT_SCHEMAS)
          echo "You can edit the schema names in the file GOSalesConfig.sh" ;;

      NORESPONSE)
          echo "No value was provided for a required field" ;;

      UNKNOWN_ARGUMENT)
          echo "Unknown argument $GOSALES_ARG " ;;

      *)
          echo "Default values can be assigned in GOSalesConfig.sh"
          echo "Exiting in error - see logs" ;;
   esac

   cleanup 1
}



cleanup()
{
   if [ -f "${GOSALES_ERROR_LOG}" ] ; then
      echo ""
      echo "GOSALES SAMPLE DATABASE SETUP ERRORS:"
      echo "(Please check the log files for more details)"
      echo "Log directory: ${GOSALES_LOG_DIR}"
      echo ---------------------------------------------
      echo ""
      cat "${GOSALES_ERROR_LOG}"
      echo ""
      echo Exiting script.  rc=$1
   fi

   exit $1
}

displaySummary()
{

  echo
  echo -----------------------------------------------------------
  echo
  
  if [ "${GOSALES_PROMPTS}" = "Y" ] ; then
    #################################################################
    # Display the summary and get a final confirmation before starting
    #################################################################

    echo Please confirm the following settings :
    echo
  else
    echo This is the configuration for the database setup :
    echo
  fi

  echo "Instance Name                 : ${GOSALES_INST}"
  echo "Database Name                 : ${GOSALES_DB}"
  echo "Storage Group Name            : ${GOSALES_STG}"
  echo "Drop and Recreate database    : ${GOSALES_CREATEDB}"

  if [ "${GOSALES_CREATE_BP_AND_TS}" = "Y" ] ; then
    echo "Create a 16k tablespace named : ${GOSALES_TS} using Bufferpool ${GOSALES_BP}"
    echo "Create a LOB Tablespace named : ${GOSALES_LOB_TS}"
  else
    echo "Use the 16k Tablespace named  : ${GOSALES_TS}"
    echo "Use the LOB Tablespace named  : ${GOSALES_LOB_TS}"
  fi
  echo "Grant permissions on the GOSALES objects to   : ${GOSALES_GRANTEES}"
  echo "Grant permissions on the GOSALESDW objects to : ${GOSALESDW_GRANTEES}"
  echo "DB2 Administration User name  : ${GOSALES_ADMIN_USERNAME}"

  if [ "${GOSALES_ONLY_GENERATE_SQL}" = "Y" ] ; then
    echo "Only generate the SQL files   : ${GOSALES_ONLY_GENERATE_SQL}"
  fi
  if [ "${GOSALES_ONLY_VERIFY}" = "Y" ] ; then
    echo "Only verify row counts        : ${GOSALES_ONLY_VERIFY}"
  fi
  echo
  if [ "${GOSALES_SKIP_IMPORT}" = "Y" ] ; then
     echo "Use the following schemas but do not import the sample data:"
  else
     echo "Import the sample data into the following schemas :"
  fi

  echo "       ${GOSALES_SCHEMA}"
  echo "       ${GOSALESHR_SCHEMA}"
  echo "       ${GOSALESMR_SCHEMA}"
  echo "       ${GOSALESRT_SCHEMA}"
  echo "       ${GOSALESCT_SCHEMA}"
  echo "       ${GOSALESDW_SCHEMA}"
  echo

  if [ "${GOSALES_CLEAN}" = "Y" ] ; then
    echo "WARNING: Existing objects in the schemas listed above will be dropped"
    echo
  fi
  if [ "${GOSALES_CREATEDB}" = "Y" ] ; then
    echo WARNING: If the database ${GOSALES_DB} already exists it will be dropped
    echo
  fi
}

#########################################################################
# Main script logic starts here
# - verify the script was called correctly
#########################################################################

if [ "${GOSALES_START}" != "1" ] ; then
   echo This script must be called from setupGSDB.sh - Quitting
   exit 1
fi


#########################################################################
# Call the file containing the subsystem, usernames and schema variables
#########################################################################
. "${GOSALES_PARENT_DIR}/GOSalesConfig.sh"


#########################################################################
# Get the operating system level
# AIX doesn't need the -e option to process the \c, but Linux does
#########################################################################
echo ""
GOSALES_OS=`uname`
GOSALES_ECHO_PROMPT="-e"
echo Operating system : ${GOSALES_OS}
if [ "${GOSALES_OS}" = "AIX" ] ; then
  GOSALES_ECHO_PROMPT=""
fi
if [ "${GOSALES_OS}" = "HP-UX" ] ; then
  GOSALES_ECHO_PROMPT=""
fi
if [ "${GOSALES_OS}" = "SunOS" ] ; then
  GOSALES_ECHO_PROMPT=""
fi

#########################################################################
# Process the command line arguments
#########################################################################

GOSALES_PROMPTS="Y"
GOSALES_CREATE_BP_AND_TS="N"
GOSALES_ONLY_GENERATE_SQL="N"
GOSALES_CLEAN="Y"
GOSALES_ONLY_COMMENTS="N"
GOSALES_ONLY_VERIFY="N"
GOSALES_SKIP_IMPORT="N"
GOSALES_DISPLAY="Y"

echo

while [ $# -ge 1 ]; do
    #convert to lowercase
    GOSALES_ARG=`echo $1 | tr 'A-Z' 'a-z'`
    case $GOSALES_ARG in
      -createdb)
          GOSALES_CREATEDB="Y" ;;
      -inst)
          shift
          if [ "$1" != "" ] ; then GOSALES_INST=$1; fi; ;;
      -database)
          shift
          if [ "$1" != "" ] ; then GOSALES_DB=$1; fi; ;;
      -userid)
          shift
          if [ "$1" != "" ] ; then GOSALES_ADMIN_USERNAME=$1; fi ;;
      -password)
          shift
          if [ "$1" != "" ] ; then GOSALES_ADMIN_PASSWORD=$1; fi ;;
      -noprompt)
          GOSALES_PROMPTS="N" ;;
      -gensql)
          GOSALES_ONLY_GENERATE_SQL="Y" ;;
      -addcomments)
          GOSALES_ONLY_COMMENTS="Y" ;;
      -verify)
          GOSALES_ONLY_VERIFY="Y" ;;
      -noimport)
          GOSALES_SKIP_IMPORT="Y" ;;
      *)
          terminate UNKNOWN_ARGUMENT ;;
    esac
    shift
done

#########################################################################
# Set up directory variables
#########################################################################
GOSALES_CURRENT_DIR=`pwd`
GOSALES_IMPORT_FILE_DIR=${GOSALES_PARENT_DIR}/../data/
GOSALES_LOG_DIR=${GOSALES_PARENT_DIR}/../logs/
GOSALES_ERROR_LOG=${GOSALES_LOG_DIR}/GOSALES_ERROR_LOG.LOG

mkdir "${GOSALES_LOG_DIR}" > /dev/null 2>&1

#########################################################################
# Delete existing log files
#########################################################################
cd "${GOSALES_LOG_DIR}"
rm -f GOSALES*.LOG > /dev/null 2>&1
cd "${GOSALES_CURRENT_DIR}"

########################################################################
# If only adding comments, get the username and skip prompts
########################################################################
if [ "${GOSALES_ONLY_COMMENTS}" = "Y" ] ; then
   GOSALES_CREATEDB="N"
   GOSALES_CREATE_BP_AND_TS="N"
   GOSALES_CLEAN="N"
   GOSALES_PROMPTS="N"
   GOSALES_DISPLAY="N"
   
   #################################################################
   # Display database name
   #################################################################
   echo "Only add table comments:"
   echo "Alias:    ${GOSALES_INST}"
   echo "Database: ${GOSALES_DB}"

   #################################################################
   # Prompt for the username to use to add the table comments
   #################################################################
   if [ "${GOSALES_ADMIN_USERNAME}" = "" ] ; then
      echo
      echo Enter the db2 administration username to use for adding  
      echo the table comments. 
      echo ${GOSALES_ECHO_PROMPT} "Please enter the DB2 admin user name : \c"
      read GOSALES_ADMIN_USERNAME
      if [ "${GOSALES_ADMIN_USERNAME}" = "" ] ; then terminate MISSING_VALUE; fi;
   fi
fi;

########################################################################
# If only verifying row counts, get the username and skip prompts
########################################################################
if [ "${GOSALES_ONLY_VERIFY}" = "Y" ] ; then
   GOSALES_CREATEDB="N"
   GOSALES_CREATE_BP_AND_TS="N"
   GOSALES_CLEAN="N"
   GOSALES_PROMPTS="N"
   GOSALES_DISPLAY="N"
   
   #################################################################
   # Display database name
   #################################################################
   echo "Only verify row counts:"
   echo "Alias:    ${GOSALES_INST}"
   echo "Database: ${GOSALES_DB}"

   #################################################################
   # Prompt for the username to use to add the table comments
   #################################################################
   if [ "${GOSALES_ADMIN_USERNAME}" = "" ] ; then
      echo
      echo Enter the db2 administration username to use for verifying  
      echo the row counts. 
      echo ${GOSALES_ECHO_PROMPT} "Please enter the DB2 admin user name : \c"
      read GOSALES_ADMIN_USERNAME
      if [ "${GOSALES_ADMIN_USERNAME}" = "" ] ; then terminate MISSING_VALUE; fi;
   fi
fi;

if [ "${GOSALES_PROMPTS}" = "Y" ] ; then

#########################################################################
# Get the database level which is used to set the datatypes for XML and
# BIGINT
#########################################################################
   echo -------------------------------------------------------------------
   echo "Press Enter at the prompts to accept the default value shown"
   echo "Default values can be specifed in the file GOSalesConfig.sh"
   echo ""
   if [ "${GOSALES_ONLY_GENERATE_SQL}" = "Y" ] ; then
       echo "Please provide values required to generate the sql files. "
       echo "(SQL will not be executed)"
       echo ""
   fi
GOSALES_CONFIRM="Y"
if [ "${GOSALES_LEVEL}" = "9" ] ; then 
      	echo ${GOSALES_ECHO_PROMPT} "DB2 for z/OS version is 9 or later. Is this correct? (Y/N) Default=Y : \c"
      read GOSALES_CONFIRM
      case ${GOSALES_CONFIRM} in
         Y|y|"") GOSALES_CONFIRM="Y" ;;
              *) GOSALES_CONFIRM="N" ;;
      esac
      if [ "${GOSALES_CONFIRM}" = "N" ] ; then
        echo "Using DB2 for z/OS version 8 syntax"
	GOSALES_LEVEL=8
      fi
else
      echo ${GOSALES_ECHO_PROMPT} "DB2 for z/OS version is 8. Is this correct? (Y/N) Default=Y : \c"
      read GOSALES_CONFIRM
      case ${GOSALES_CONFIRM} in
         Y|y|"") GOSALES_CONFIRM="Y" ;;
              *) GOSALES_CONFIRM="N" ;;
      esac
      if [ "${GOSALES_CONFIRM}" = "N" ] ; then
        echo "Using DB2 for z/OS version 9 syntax"
	GOSALES_LEVEL=9
      else
	GOSALES_LEVEL=8
      fi
fi

   echo ""
   echo -------------------------------------------------------------------
   echo "Press Enter at the prompts to accept the default value shown"
   echo "Default values can be specifed in the file GOSalesConfig.sh"
   echo ""
   echo -------------------------------------------------------------------
   echo "Please enter the database alias of the remote DB2 z/OS location name"
   echo ${GOSALES_ECHO_PROMPT} "for the GOSales sample database (default=${GOSALES_INST}) : \c"
   read GOSALES_USERINPUT
   if [ "${GOSALES_USERINPUT}" != "" ] ; then
      GOSALES_INST=${GOSALES_USERINPUT}
   fi

   echo ""
   echo -------------------------------------------------------------------
   echo "Please enter the name of the database to be used for the"
   echo ${GOSALES_ECHO_PROMPT} "GOSales sample data (default=${GOSALES_DB}) : \c"
   read GOSALES_USERINPUT
   if [ "${GOSALES_USERINPUT}" != "" ] ; then
      GOSALES_DB=${GOSALES_USERINPUT}
   fi

   echo ""
   echo -------------------------------------------------------------------
   echo "Please enter the name of the storage group to be used for the"
   echo ${GOSALES_ECHO_PROMPT} "GOSales sample database (default=${GOSALES_STG}) : \c"
   read GOSALES_USERINPUT
   if [ "${GOSALES_USERINPUT}" != "" ] ; then
      GOSALES_STG=${GOSALES_USERINPUT}
   fi


   if [ "${GOSALES_CREATEDB}" = "" ] ; then
      echo ""
      echo -------------------------------------------------------------------
      echo This script can optionally create the ${GOSALES_DB} database. 
      echo Answering Yes to the question below will cause any existing  
      echo databases with the same name to be dropped.
      echo ${GOSALES_ECHO_PROMPT} "Would you like to create the database ${GOSALES_DB}? (Y/N) Default=Y : \c"
      read GOSALES_CREATEDB
      case ${GOSALES_CREATEDB} in
         Y|y|"") GOSALES_CREATEDB="Y" ;;
              *) GOSALES_CREATEDB="N" ;;
      esac
   fi


   ############################################
   #Check if the values are all set
   ############################################
   if [ "${GOSALES_INST}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value(GOSALES_INST) \n => Enter a value for the DB2 subsystem name: \c"
      read GOSALES_INST;
      if [ "${GOSALES_INST}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi
   if [ "${GOSALES_DB}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value(GOSALES_DB) \n => Enter a value for the DB2 database name: \c"
      read GOSALES_DB;
      if [ "${GOSALES_DB}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi

   if [ "${GOSALES_TS}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value(GOSALES_TS) \n => Enter a value for the tablespace that you want to create the tables in: \c"
      read GOSALES_TS;
      if [ "${GOSALES_TS}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi
   
   if [ "${GOSALES_LOB_TS}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value(GOSALES_LOB_TS) \n => Enter a value for the LOB tablespace name: \c"
      read GOSALES_LOB_TS;
      if [ "${GOSALES_LOB_TS}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi

   if [ "${GOSALES_BP}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value(GOSALES_BP) \n => Enter a value for the 16K buffer pool name: \c"
      read GOSALES_BP;
      if [ "${GOSALES_BP}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi

   if [ "${GOSALES_STG}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value(GOSALES_STG) \n => Enter a value for the storage group name: \c"
      read GOSALES_STG
      if [ "${GOSALES_STG}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi


   if [ "${GOSALES_GRANTEES}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value ( GOSALES_GRANTEES ) \n => Enter the "GRANT TO" option for the GOSALES schema: \c"
      read GOSALES_GRANTEES;
      if [ "${GOSALES_GRANTEES}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi

   if [ "${GOSALESDW_GRANTEES}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value ( GOSALESDW_GRANTEES ) \n => Enter the "GRANT TO" option for the GOSALESDW schema: \c"
      read GOSALESDW_GRANTEES;
      if [ "${GOSALESDW_GRANTEES}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi

   if [ "${GOSALES_SCHEMA}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value ( GOSALES_SCHEMA ) \n => Enter a name for the GOSALES schema: \c"
      read GOSALES_SCHEMA;
      if [ "${GOSALES_SCHEMA}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi

   if [ "${GOSALESHR_SCHEMA}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value ( GOSALESHR_SCHEMA ) \n => Enter a name for the GOSALESHR schema: \c"
      read GOSALESHR_SCHEMA;
      if [ "${GOSALESHR_SCHEMA}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi

   if [ "${GOSALESMR_SCHEMA}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value ( GOSALESMR_SCHEMA ) \n => Enter a name for the GOSALESMR schema: \c"
      read GOSALESMR_SCHEMA;
      if [ "${GOSALESMR_SCHEMA}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi

   if [ "${GOSALESRT_SCHEMA}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value ( GOSALESRT_SCHEMA ) \n => Enter a name for the GOSALESRT schema: \c"
      read GOSALESRT_SCHEMA;
      if [ "${GOSALESRT_SCHEMA}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi

   if [ "${GOSALESCT_SCHEMA}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value ( GOSALESCT_SCHEMA ) \n => Enter a name for the GOSALESCT schema: \c"
      read GOSALESCT_SCHEMA;
      if [ "${GOSALESCT_SCHEMA}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi

   if [ "${GOSALESDW_SCHEMA}" = "" ] ; then
      echo ${GOSALES_ECHO_PROMPT} "Missing value ( GOSALESDW_SCHEMA ) \n => Enter a name for the GOSALESDW schema: \c"
      read GOSALESDW_SCHEMA;
      if [ "${GOSALESDW_SCHEMA}" = "" ] ; then terminate MISSING_VALUE;  fi;
   fi
else
   # if GOSALES_PROMPTS = N
   if [ "${GOSALES_CREATEDB}" = "" ] ; then
      GOSALES_CREATEDB="N";
   fi
fi

######################################################################
#Skip the prompts if the user provided the information in setupGSDB.sh
######################################################################

if [ "${GOSALES_PROMPTS}" = "Y" ] ; then

   if [ "${GOSALES_CREATEDB}" = "Y" ] ; then
            echo ${GOSALES_ECHO_PROMPT} "Are you sure you want to drop the database if it already exists? (Y/N) Default=Y: \c"
            read GOSALES_CREATEDB
            case ${GOSALES_CREATEDB} in
               Y|y|"") GOSALES_CREATEDB="Y" ;;
                    *) GOSALES_CREATEDB="N" ;;
            esac 
     # esac
   fi

   #################################################################
   # Ask if user wants to create the tablespaces
   # Only prompt if we are not already creating the database
   #################################################################

   GOSALES_CREATE_BP_AND_TS="Y"
   if [ "${GOSALES_CREATEDB}" = "N" ] ; then
      echo
      echo To import the data the database needs to contain a 16K tablespace
      echo and a LOB tablespace. Do you want to create the 
      echo ${GOSALES_ECHO_PROMPT} "tablespaces now? (Y/N) Default=Y : \c"
      read GOSALES_CREATE_BP_AND_TS;
      case ${GOSALES_CREATE_BP_AND_TS} in
         Y|y|"") GOSALES_CREATE_BP_AND_TS="Y" ;;
              *) GOSALES_CREATE_BP_AND_TS="N" ;;
      esac
   fi

   if [ "${GOSALES_CREATE_BP_AND_TS}" = "Y" ] ; then
      # Ensure we have a name for the buffer pool
      if [ "${GOSALES_BP}" = "" ] ; then
         echo
         echo ${GOSALES_ECHO_PROMPT} "Enter the name for the buffer pool : \c"
         read GOSALES_BP
         if [ "${GOSALES_BP}" = "" ] ; then terminate MISSING_VALUE; fi;
      fi

      # Ensure we have a name for the tablespace
      if [ "${GOSALES_TS}" = "" ] ; then
         echo
         echo ${GOSALES_ECHO_PROMPT} "Enter the name for the new tablespace : \c"
         read GOSALES_TS
         if [ "${GOSALES_TS}" = "" ] ; then terminate MISSING_VALUE; fi;
      fi
      # Ensure we have a name for the LOB tablespace
      if [ "${GOSALES_LOB_TS}" = "" ] ; then
         echo
         echo ${GOSALES_ECHO_PROMPT} "Enter the name for the new LOB tablespace : \c"
         read GOSALES_LOB_TS
         if [ "${GOSALES_LOB_TS}" = "" ] ; then terminate MISSING_VALUE; fi;
      fi
      
    else
      # Ensure we have a name for the buffer pool
      if [ "${GOSALES_BP}" = "" ] ; then
         echo
         echo ${GOSALES_ECHO_PROMPT} "Enter the name for the 16K buffer pool : \c"
         read GOSALES_BP
         if [ "${GOSALES_BP}" = "" ] ; then terminate MISSING_VALUE; fi;
      fi
      # Ensure we have a name for the existing tablespace
      if [ "${GOSALES_TS}" = "" ] ; then
         echo
         echo ${GOSALES_ECHO_PROMPT} "Enter the name for the existing tablespace : \c"
         read GOSALES_TS
         if [ "${GOSALES_TS}" = "" ] ; then terminate MISSING_VALUE; fi;
      fi
      # Ensure we have a name for the existing LOB tablespace
      if [ "${GOSALES_LOB_TS}" = "" ] ; then
         echo
         echo ${GOSALES_ECHO_PROMPT} "Enter the name for the existing LOB tablespace : \c"
         read GOSALES_LOB_TS
         if [ "${GOSALES_LOB_TS}" = "" ] ; then terminate MISSING_VALUE; fi;
      fi
   fi

fi #GOSALES_PROMPTS==Y

#################################################################
# Prompt for the username to use to run import
#################################################################
if [ "${GOSALES_ADMIN_USERNAME}" = "" ] ; then
   echo
   echo Enter the db2 administration username for creating the database
   echo and importing the data. 
   echo ${GOSALES_ECHO_PROMPT} "Please enter the DB2 admin user name : \c"
   read GOSALES_ADMIN_USERNAME
   if [ "${GOSALES_ADMIN_USERNAME}" = "" ] ; then terminate MISSING_VALUE; fi;
fi

if [ "${GOSALES_CREATEDB}" = "Y" ] ; then
   GOSALES_CREATE_BP_AND_TS="Y"
   GOSALES_CLEAN="N"
fi;

if [ "${GOSALES_DISPLAY}" = "Y" ] ; then
	displaySummary
fi;

if [ "${GOSALES_PROMPTS}" = "Y" ] ; then
  if [ "${GOSALES_ONLY_GENERATE_SQL}" = "N" ] ; then
    echo ${GOSALES_ECHO_PROMPT} "Continue creating the sample data with these settings? (Y/N) Default=Y :\c"
  else
    echo ${GOSALES_ECHO_PROMPT} "Generate but do not execute the sql for these settings? (Y/N) Default=Y :\c"
  fi;

   read GOSALES_USER_RESPONSE
   case ${GOSALES_USER_RESPONSE} in
      Y|y|"") echo "" ;;
           *) terminate USER_EXIT ;;
   esac

fi

if [ "${GOSALES_LEVEL}" = "8" ] ; then 
   GOSALES_XML="VARCHAR(1000)"
   GOSALES_BIGINT="DECIMAL(19,0)"
else
   GOSALES_XML=XML
   GOSALES_BIGINT=BIGINT
fi

echo Please wait ...
echo

################################################
# Create the sql files by running the batch files
################################################

if [ "${GOSALES_CREATEDB}" = "Y" -a -f GOSALES_CREATE_DB.sh ] ; then
   . ./GOSALES_CREATE_DB.sh > GOSALES_CREATE_DB.SQL
fi

if [ "${GOSALES_CREATE_BP_AND_TS}" = "Y" -a -f GOSALES_CREATE_TS.sh ] ; then
   . ./GOSALES_CREATE_TS.sh > GOSALES_CREATE_TS.SQL
fi

#TABLES
if [ -f GOSALES_TABLES.sh ] ; then . ./GOSALES_TABLES.sh > GOSALES_TABLES.SQL ; fi;
if [ -f GOSALESHR_TABLES.sh ] ; then . ./GOSALESHR_TABLES.sh > GOSALESHR_TABLES.SQL ; fi;
if [ -f GOSALESMR_TABLES.sh ] ; then . ./GOSALESMR_TABLES.sh > GOSALESMR_TABLES.SQL ; fi;
if [ -f GOSALESRT_TABLES.sh ] ; then . ./GOSALESRT_TABLES.sh > GOSALESRT_TABLES.SQL ; fi;
if [ -f GOSALESCT_TABLES.sh ] ; then . ./GOSALESCT_TABLES.sh > GOSALESCT_TABLES.SQL ; fi;
if [ -f GOSALESDW_TABLES.sh ] ; then . ./GOSALESDW_TABLES.sh > GOSALESDW_TABLES.SQL ; fi;

#AUXILIARY TABLES
if [ -f GOSALES_LOB_TABLES.sh ] ; then . ./GOSALES_LOB_TABLES.sh > GOSALES_LOB_TABLES.SQL ; fi;
if [ -f GOSALESHR_LOB_TABLES.sh ] ; then . ./GOSALESHR_LOB_TABLES.sh > GOSALESHR_LOB_TABLES.SQL ; fi;
if [ -f GOSALESMR_LOB_TABLES.sh ] ; then . ./GOSALESMR_LOB_TABLES.sh > GOSALESMR_LOB_TABLES.SQL ; fi;
if [ -f GOSALESRT_LOB_TABLES.sh ] ; then . ./GOSALESRT_LOB_TABLES.sh > GOSALESRT_LOB_TABLES.SQL ; fi;
if [ -f GOSALESCT_LOB_TABLES.sh ] ; then . ./GOSALESCT_LOB_TABLES.sh > GOSALESCT_LOB_TABLES.SQL ; fi;
if [ -f GOSALESDW_LOB_TABLES.sh ] ; then . ./GOSALESDW_LOB_TABLES.sh > GOSALESDW__LOB_TABLES.SQL ; fi;

#LOAD THE TABLES
. ./GOSALES_LOAD.sh > GOSALES_LOAD.SQL
if [ "${GOSALES_LEVEL}" = "8" ] ; then 
. ./GOSALESCT_PTNR_ACTIVITY.sh > GOSALESCT_PTNR_ACTIVITY.SQL
fi

#DROP TABLES
. ./GOSALES_DROP.sh 

#GRANTS
if [ -f GOSALES_GRANTS.sh ] ; then . ./GOSALES_GRANTS.sh > GOSALES_GRANTS.SQL ; fi;
if [ -f GOSALESHR_GRANTS.sh ] ; then . ./GOSALESHR_GRANTS.sh > GOSALESHR_GRANTS.SQL ; fi;
if [ -f GOSALESMR_GRANTS.sh ] ; then . ./GOSALESMR_GRANTS.sh > GOSALESMR_GRANTS.SQL ; fi;
if [ -f GOSALESRT_GRANTS.sh ] ; then . ./GOSALESRT_GRANTS.sh > GOSALESRT_GRANTS.SQL ; fi;
if [ -f GOSALESCT_GRANTS.sh ] ; then . ./GOSALESCT_GRANTS.sh > GOSALESCT_GRANTS.SQL ; fi;
if [ -f GOSALESDW_GRANTS.sh ] ; then . ./GOSALESDW_GRANTS.sh > GOSALESDW_GRANTS.SQL ; fi;

#PRIMARY KEYS
if [ -f GOSALES_PK.sh ] ; then . ./GOSALES_PK.sh > GOSALES_PK.SQL ; fi;
if [ -f GOSALESHR_PK.sh ] ; then . ./GOSALESHR_PK.sh > GOSALESHR_PK.SQL ; fi;
if [ -f GOSALESMR_PK.sh ] ; then . ./GOSALESMR_PK.sh > GOSALESMR_PK.SQL ; fi;
if [ -f GOSALESRT_PK.sh ] ; then . ./GOSALESRT_PK.sh > GOSALESRT_PK.SQL ; fi;
if [ -f GOSALESCT_PK.sh ] ; then . ./GOSALESCT_PK.sh > GOSALESCT_PK.SQL ; fi;
if [ -f GOSALESDW_PK.sh ] ; then . ./GOSALESDW_PK.sh > GOSALESDW_PK.SQL ; fi;

#INDEXES
if [ -f GOSALES_INDEXES.sh ] ; then . ./GOSALES_INDEXES.sh > GOSALES_INDEXES.SQL ; fi;
if [ -f GOSALESHR_INDEXES.sh ] ; then . ./GOSALESHR_INDEXES.sh > GOSALESHR_INDEXES.SQL ; fi;
if [ -f GOSALESMR_INDEXES.sh ] ; then . ./GOSALESMR_INDEXES.sh > GOSALESMR_INDEXES.SQL ; fi;
if [ -f GOSALESRT_INDEXES.sh ] ; then . ./GOSALESRT_INDEXES.sh > GOSALESRT_INDEXES.SQL ; fi;
if [ -f GOSALESCT_INDEXES.sh ] ; then . ./GOSALESCT_INDEXES.sh > GOSALESCT_INDEXES.SQL ; fi;
if [ -f GOSALESDW_INDEXES.sh ] ; then . ./GOSALESDW_INDEXES.sh > GOSALESDW_INDEXES.SQL ; fi;

#CONSTRAINTS
if [ -f GOSALES_CONSTRAINTS.sh ] ; then . ./GOSALES_CONSTRAINTS.sh > GOSALES_CONSTRAINTS.SQL ; fi;
if [ -f GOSALESHR_CONSTRAINTS.sh ] ; then . ./GOSALESHR_CONSTRAINTS.sh > GOSALESHR_CONSTRAINTS.SQL ; fi;
if [ -f GOSALESMR_CONSTRAINTS.sh ] ; then . ./GOSALESMR_CONSTRAINTS.sh > GOSALESMR_CONSTRAINTS.SQL ; fi;
if [ -f GOSALESRT_CONSTRAINTS.sh ] ; then . ./GOSALESRT_CONSTRAINTS.sh > GOSALESRT_CONSTRAINTS.SQL ; fi;
if [ -f GOSALESCT_CONSTRAINTS.sh ] ; then . ./GOSALESCT_CONSTRAINTS.sh > GOSALESCT_CONSTRAINTS.SQL ; fi;
if [ -f GOSALESDW_CONSTRAINTS.sh ] ; then . ./GOSALESDW_CONSTRAINTS.sh > GOSALESDW_CONSTRAINTS.SQL ; fi;

#VIEWS
if [ -f GOSALES_VIEWS.sh ] ; then . ./GOSALES_VIEWS.sh > GOSALES_VIEWS.SQL ; fi;
if [ -f GOSALESHR_VIEWS.sh ] ; then . ./GOSALESHR_VIEWS.sh > GOSALESHR_VIEWS.SQL ; fi;
if [ -f GOSALESMR_VIEWS.sh ] ; then . ./GOSALESMR_VIEWS.sh > GOSALESMR_VIEWS.SQL ; fi;
if [ -f GOSALESRT_VIEWS.sh ] ; then . ./GOSALESRT_VIEWS.sh > GOSALESRT_VIEWS.SQL ; fi;
if [ -f GOSALESCT_VIEWS.sh ] ; then . ./GOSALESCT_VIEWS.sh > GOSALESCT_VIEWS.SQL ; fi;
if [ -f GOSALESDW_VIEWS.sh ] ; then . ./GOSALESDW_VIEWS.sh > GOSALESDW_VIEWS.SQL ; fi;

#RUNSTATS
if [ -f GOSALES_RUNSTATS.sh ] ; then . ./GOSALES_RUNSTATS.sh > GOSALES_RUNSTATS.TXT ; fi;

# Add comments
if [ -f GOSALES_ADD_COMMENTS.sh ] ; then . ./GOSALES_ADD_COMMENTS.sh > GOSALES_ADD_COMMENTS.SQL ;
fi;

#Verify Table
if [ -f GOSALES_VERIFY.sh ] ; then . ./GOSALES_VERIFY.sh > GOSALES_VERIFY.SQL ; fi;

##############################################
# Run the scripts to execute the generated SQL
##############################################
if [ "${GOSALES_ONLY_GENERATE_SQL}" = "N" ] ; then
. ./GOSALES_RUN_SCRIPTS.sh
else
  echo "Sql files are located in ${GOSALES_SCRIPT_DIR}"
fi

# Finished - invoke the cleanup routine.
cleanup 0;
