@echo OFF
REM *******************************************************************
REM *  5724-E34
REM *  (c) Copyright IBM Corporation 2008, 2009.
REM *  All rights reserved.
REM *
REM *  The source code for this program is not published or otherwise
REM *  divested of its trade secrets, irrespective of what has been
REM *  deposited with the U.S. Copyright Office.
REM *******************************************************************
REM *
REM ******************************************************************
REM *  File: GOSALES_RUN_SCRIPTS.bat
REM *
REM *  Description:
REM *     This script must be started from the setupGSDB.bat
REM *     script.
REM *     This file performs one or more of the following functions :
REM *       - ATTACH to the NODENAME
REM *       - Creates the database, bufferpool and tablespaces
REM *       - Connects to the database
REM *       - Executes the SQL scripts that were generated in the
REM *         RUN_GOSALES_IMPORT.bat file to create the tables, indexes,
REM *         foreign keys, views, privileges and stored procedures that
REM *         make up the GOSALES database
REM *
REM ******************************************************************
SETLOCAL
echo.
REM ************************************************************************
REM * Verify that the script was called correctly
REM ************************************************************************
IF "%GOSALES_START%"=="1" GOTO CONTINUE_RUN
echo THIS SCRIPT MUST BE CALLED FROM "setupGSDB.bat" - QUITTING
GOTO :EOF
:CONTINUE_RUN

IF "%GOSALES_ONLY_VERIFY%"=="Y" GOTO CONNECT_DB
IF "%GOSALES_ONLY_COMMENTS%"=="Y" GOTO CONNECT_DB

REM ******************************************************************
REM * Create the database
REM * - needs to attach
REM ******************************************************************
echo Starting GOSALES_RUN_SCRIPTS

db2 connect reset 1>NUL 2>NUL

if /I "%GOSALES_CREATEDB%" == "N" goto CONNECT_DB
  if NOT EXIST GOSALES_CREATE_DB.SQL goto CONNECT_DB
   echo Create database started at %time% > "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"

   REM Attach if the NODE is provided
   if "%GOSALES_NODENAME%" == "" goto CREATE_DB
      if "%GOSALES_ADMIN_USERNAME%" neq "" goto ATTACH_WITH_USER

         db2 attach to %GOSALES_NODENAME%
         if ERRORLEVEL 1 goto ATTACH_ERROR
         goto ATTACH_SUCCESS

      :ATTACH_WITH_USER
         if "%GOSALES_ADMIN_PASSWORD%" neq "" goto ATTACH_WITH_USER_AND_PASSWORD
           db2 attach to %GOSALES_NODENAME% user %GOSALES_ADMIN_USERNAME%
           if ERRORLEVEL 1 goto ATTACH_ERROR
           goto ATTACH_SUCCESS

      :ATTACH_WITH_USER_AND_PASSWORD
         db2 attach to %GOSALES_NODENAME% user %GOSALES_ADMIN_USERNAME% using %GOSALES_ADMIN_PASSWORD%
         if ERRORLEVEL 1 goto ATTACH_ERROR
         goto ATTACH_SUCCESS

:ATTACH_ERROR
   echo ATTACH to node %GOSALES_NODENAME% failed
   echo ATTACH to node %GOSALES_NODENAME% failed >> "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"
   goto CLEANUP

:ATTACH_SUCCESS
   echo ATTACH to node %GOSALES_NODENAME% was successful >> "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"

:CREATE_DB

   REM ******************************************************************
   REM * Drop the existing database in the shell since we dont worry
   REM * about the error of the result
   REM ******************************************************************
   echo Dropping existing database %GOSALES_INST% if found
   db2 drop database %GOSALES_INST% >> "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"

   REM ******************************************************************
   REM * Run the script to create the database
   REM ******************************************************************
   echo Creating database %GOSALES_INST%
   db2 -td@ -vf GOSALES_CREATE_DB.SQL >> "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"

   IF ERRORLEVEL 1 goto CREATE_DATABASE_ERROR

   REM ******************************************************************
   REM * If the user running this script is not the admin username provided
   REM * then we need to grant that admin user admin permissions on the
   REM * newly created database.  This is only an issue where the default
   REM * NODE is used, so an implicit connect is used
   REM ******************************************************************
   REM if "%GOSALES_NODENAME%" neq "" goto CONNECT_DB
   if "%GOSALES_ADMIN_USERNAME%" == "" goto CONNECT_DB
      echo Granting DBADM permissions to %GOSALES_ADMIN_USERNAME% >> "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"
      db2 connect to %GOSALES_INST%  >> "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"
      db2 grant DBADM on database to USER %GOSALES_ADMIN_USERNAME% >> "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"
      if ERRORLEVEL 1 echo Error granting DBADM permission to %GOSALES_ADMIN_USERNAME%

   echo Create database completed at %time% >> "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"

REM **************************************
REM * Connect to the database
REM **************************************
:CONNECT_DB

echo Connecting to %GOSALES_INST%
db2 connect reset > NUL
db2 terminate > NUL

IF "%GOSALES_ADMIN_USERNAME%" == "" goto CONNECT_WITHOUT_USERID

IF "%GOSALES_ADMIN_PASSWORD%" neq "" goto CONNECT_WITH_PASSWORD
  db2 connect to %GOSALES_INST% user %GOSALES_ADMIN_USERNAME%
  IF ERRORLEVEL 1 GOTO CONNECT_ERROR
  goto CREATE_BUFFER_POOLS

:CONNECT_WITH_PASSWORD
  db2 connect to %GOSALES_INST% user %GOSALES_ADMIN_USERNAME% using %GOSALES_ADMIN_PASSWORD%
  IF ERRORLEVEL 1 GOTO CONNECT_ERROR
  goto CREATE_BUFFER_POOLS

:CONNECT_WITHOUT_USERID
  db2 connect to %GOSALES_INST%
  IF ERRORLEVEL 1 GOTO CONNECT_ERROR

:CREATE_BUFFER_POOLS

IF "%GOSALES_ONLY_VERIFY%"=="Y" GOTO VERIFY
IF "%GOSALES_ONLY_COMMENTS%" == "Y" GOTO ADD_COMMENTS

REM **************************************
REM * Create the bufferpool and tablespace
REM * Skip if not required
REM **************************************
IF /I "%GOSALES_CREATE_BP_AND_TS%" == "N" GOTO CLEAN_DATABASE
echo Creating bufferpool and tablespace.
db2 -td@ -f GOSALES_CREATE_TS.SQL > "%GOSALES_LOG_DIR%GOSALES_CREATE_TS.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLESPACE_ERROR


:CLEAN_DATABASE
REM **************************************
REM * Drop existing tables, views and procedures if the option is requested
REM **************************************
IF "%GOSALES_CREATEDB%"=="Y" goto CREATE_TABLES
IF "%GOSALES_CLEAN%"=="N" goto CREATE_TABLES

IF EXIST GOSALES_DROP.SQL db2 -td@ -f GOSALES_DROP.SQL > "%GOSALES_LOG_DIR%GOSALES_DROP.LOG"
IF EXIST GOSALES_DROP.SQL IF ERRORLEVEL 1 echo Error dropping existing tables
IF EXIST WAREHOUSE_TUTORIAL_CLEANUP.SQL db2 -td@ -vf WAREHOUSE_TUTORIAL_CLEANUP.SQL >> "%GOSALES_LOG_DIR%GOSALES_DROP.LOG"

:CREATE_TABLES
REM **************************************
REM * Create the tables
REM **************************************
echo Creating tables.
IF EXIST GOSALES_TABLES.SQL db2 -td@ -f GOSALES_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALES_TABLES.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLE_ERROR
IF EXIST GOSALESHR_TABLES.SQL db2 -td@ -f GOSALESHR_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESHR_TABLES.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLE_ERROR
IF EXIST GOSALESMR_TABLES.SQL db2 -td@ -f GOSALESMR_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESMR_TABLES.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLE_ERROR
IF EXIST GOSALESRT_TABLES.SQL db2 -td@ -f GOSALESRT_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESRT_TABLES.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLE_ERROR
IF EXIST GOSALESCT_TABLES.SQL db2 -td@ -f GOSALESCT_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESCT_TABLES.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLE_ERROR
IF EXIST GOSALESDW_TABLES.SQL db2 -td@ -f GOSALESDW_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESDW_TABLES.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLE_ERROR

REM **************************************
REM * Load the data
REM **************************************
IF "%GOSALES_SKIP_IMPORT%"=="Y" goto SKIP

echo starting load at %time% > "%GOSALES_LOG_DIR%GOSALES_LOAD.LOG"
echo Loading data.
db2 -td@ -f GOSALES_LOAD.SQL >> "%GOSALES_LOG_DIR%GOSALES_LOAD.LOG"

if "%GOSALES_XML_SUPPORT%" == "Y" GOTO SKIP
db2 -td@ -vf GOSALESCT_PTNR_ACTIVITY.SQL >> "%GOSALES_LOG_DIR%GOSALES_LOAD.LOG"
:SKIP

IF ERRORLEVEL 1 GOTO IMPORT_ERROR

echo ending load at %time% >> "%GOSALES_LOG_DIR%GOSALES_LOAD.LOG"

:SKIP

REM **************************************
REM * Create primary keys
REM **************************************
echo Creating primary keys
IF EXIST GOSALES_PK.SQL db2 -td@ -f GOSALES_PK.SQL > "%GOSALES_LOG_DIR%GOSALES_PK.LOG"
IF EXIST GOSALES_PK.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALES PRIMARY KEYS (see log file GOSALES_PK.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESHR_PK.SQL db2 -td@ -f GOSALESHR_PK.SQL > "%GOSALES_LOG_DIR%GOSALESHR_PK.LOG"
IF EXIST GOSALESHR_PK.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESHR PRIMARY KEYS (see log file GOSALESHR_PK.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESMR_PK.SQL db2 -td@ -f GOSALESMR_PK.SQL > "%GOSALES_LOG_DIR%GOSALESMR_PK.LOG"
IF EXIST GOSALESMR_PK.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESMR PRIMARY KEYS (see log file GOSALESMR_PK.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESRT_PK.SQL db2 -td@ -f GOSALESRT_PK.SQL > "%GOSALES_LOG_DIR%GOSALESRT_PK.LOG"
IF EXIST GOSALESRT_PK.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESRT PRIMARY KEYS (see log file GOSALESRT_PK.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESCT_PK.SQL db2 -td@ -f GOSALESCT_PK.SQL > "%GOSALES_LOG_DIR%GOSALESCT_PK.LOG"
IF EXIST GOSALESCT_PK.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESCT PRIMARY KEYS (see log file GOSALESCT_PK.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESDW_PK.SQL db2 -td@ -f GOSALESDW_PK.SQL > "%GOSALES_LOG_DIR%GOSALESDW_PK.LOG"
IF EXIST GOSALESDW_PK.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESDW PRIMARY KEYS (see log file GOSALESDW_PK.LOG)  >> %GOSALES_ERROR_LOG%

REM **************************************
REM * Create indexes
REM **************************************
echo Creating indexes
IF EXIST GOSALES_INDEXES.SQL db2 -td@ -f GOSALES_INDEXES.SQL > "%GOSALES_LOG_DIR%GOSALES_INDEXES.LOG"
IF EXIST GOSALES_INDEXES.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALES INDEXES (see log file GOSALES_INDEXES.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESHR_INDEXES.SQL db2 -td@ -f GOSALESHR_INDEXES.SQL > "%GOSALES_LOG_DIR%GOSALESHR_INDEXES.LOG"
IF EXIST GOSALESHR_INDEXES.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESHR INDEXES (see log file GOSALESHR_INDEXES.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESMR_INDEXES.SQL db2 -td@ -f GOSALESMR_INDEXES.SQL > "%GOSALES_LOG_DIR%GOSALESMR_INDEXES.LOG"
IF EXIST GOSALESMR_INDEXES.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESMR INDEXES (see log file GOSALESMR_INDEXES.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESRT_INDEXES.SQL db2 -td@ -f GOSALESRT_INDEXES.SQL > "%GOSALES_LOG_DIR%GOSALESRT_INDEXES.LOG"
IF EXIST GOSALESRT_INDEXES.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESRT INDEXES (see log file GOSALESRT_INDEXES.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESCT_INDEXES.SQL db2 -td@ -f GOSALESCT_INDEXES.SQL > "%GOSALES_LOG_DIR%GOSALESCT_INDEXES.LOG"
IF EXIST GOSALESCT_INDEXES.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESCT INDEXES (see log file GOSALESCT_INDEXES.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESDW_INDEXES.SQL db2 -td@ -f GOSALESDW_INDEXES.SQL > "%GOSALES_LOG_DIR%GOSALESDW_INDEXES.LOG"
IF EXIST GOSALESDW_INDEXES.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESDW INDEXES (see log file GOSALESDW_INDEXES.LOG)  >> %GOSALES_ERROR_LOG%

REM **************************************
REM * Create constraints
REM **************************************
echo Creating constraints.
IF EXIST GOSALES_CONSTRAINTS.SQL db2 -td@ -f GOSALES_CONSTRAINTS.SQL > "%GOSALES_LOG_DIR%GOSALES_CONSTRAINTS.LOG"
IF EXIST GOSALES_CONSTRAINTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALES CONSTRAINTS (see log file GOSALES_CONSTRAINTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESHR_CONSTRAINTS.SQL db2 -td@ -f GOSALESHR_CONSTRAINTS.SQL > "%GOSALES_LOG_DIR%GOSALESHR_CONSTRAINTS.LOG"
IF EXIST GOSALESHR_CONSTRAINTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESHR CONSTRAINTS (see log file GOSALESHR_CONSTRAINTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESMR_CONSTRAINTS.SQL db2 -td@ -f GOSALESMR_CONSTRAINTS.SQL > "%GOSALES_LOG_DIR%GOSALESMR_CONSTRAINTS.LOG"
IF EXIST GOSALESMR_CONSTRAINTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESMR CONSTRAINTS (see log file GOSALESMR_CONSTRAINTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESRT_CONSTRAINTS.SQL db2 -td@ -f GOSALESRT_CONSTRAINTS.SQL > "%GOSALES_LOG_DIR%GOSALESRT_CONSTRAINTS.LOG"
IF EXIST GOSALESRT_CONSTRAINTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESRT CONSTRAINTS (see log file GOSALESRT_CONSTRAINTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESCT_CONSTRAINTS.SQL db2 -td@ -f GOSALESCT_CONSTRAINTS.SQL > "%GOSALES_LOG_DIR%GOSALESCT_CONSTRAINTS.LOG"
IF EXIST GOSALESCT_CONSTRAINTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESCT CONSTRAINTS (see log file GOSALESCT_CONSTRAINTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESDW_CONSTRAINTS.SQL db2 -td@ -f GOSALESDW_CONSTRAINTS.SQL > "%GOSALES_LOG_DIR%GOSALESDW_CONSTRAINTS.LOG"
IF EXIST GOSALESDW_CONSTRAINTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESDW CONSTRAINTS (see log file GOSALESDW_CONSTRAINTS.LOG)  >> %GOSALES_ERROR_LOG%

REM **************************************
REM * Create stored procedures
REM **************************************
echo Creating stored procedures
IF EXIST GOSALES_SP.SQL db2 -td@ -f GOSALES_SP.SQL > "%GOSALES_LOG_DIR%GOSALES_SP.LOG"
IF EXIST GOSALES_SP.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALES STORED PROCEDURES (see log file GOSALES_SP.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESHR_SP.SQL db2 -td@ -f GOSALESHR_SP.SQL > "%GOSALES_LOG_DIR%GOSALESHR_SP.LOG"
IF EXIST GOSALESHR_SP.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESHR STORED PROCEDURES (see log file GOSALESHR_SP.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESMR_SP.SQL db2 -td@ -f GOSALESMR_SP.SQL > "%GOSALES_LOG_DIR%GOSALESMR_SP.LOG"
IF EXIST GOSALESMR_SP.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESMR STORED PROCEDURES (see log file GOSALESMR_SP.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESRT_SP.SQL db2 -td@ -f GOSALESRT_SP.SQL > "%GOSALES_LOG_DIR%GOSALESRT_SP.LOG"
IF EXIST GOSALESRT_SP.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESRT STORED PROCEDURES (see log file GOSALESRT_SP.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESCT_SP.SQL db2 -td@ -f GOSALESCT_SP.SQL > "%GOSALES_LOG_DIR%GOSALESCT_SP.LOG"
IF EXIST GOSALESCT_SP.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESCT STORED PROCEDURES (see log file GOSALESCT_SP.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESDW_SP.SQL db2 -td@ -f GOSALESDW_SP.SQL > "%GOSALES_LOG_DIR%GOSALESDW_SP.LOG"
IF EXIST GOSALESDW_SP.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESDW STORED PROCEDURES (see log file GOSALESDW_SP.LOG) >> %GOSALES_ERROR_LOG%

REM **************************************
REM * Create views
REM **************************************
echo Creating views
IF EXIST GOSALES_VIEWS.SQL db2 -td@ -f GOSALES_VIEWS.SQL > "%GOSALES_LOG_DIR%GOSALES_VIEWS.LOG"
IF EXIST GOSALES_VIEWS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALES VIEWS (see log file GOSALES_VIEWS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESHR_VIEWS.SQL db2 -td@ -f GOSALESHR_VIEWS.SQL > "%GOSALES_LOG_DIR%GOSALESHR_VIEWS.LOG"
IF EXIST GOSALESHR_VIEWS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESHR VIEWS (see log file GOSALESHR_VIEWS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESMR_VIEWS.SQL db2 -td@ -f GOSALESMR_VIEWS.SQL > "%GOSALES_LOG_DIR%GOSALESMR_VIEWS.LOG"
IF EXIST GOSALESMR_VIEWS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESMR VIEWS (see log file GOSALESMR_VIEWS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESRT_VIEWS.SQL db2 -td@ -f GOSALESRT_VIEWS.SQL > "%GOSALES_LOG_DIR%GOSALESRT_VIEWS.LOG"
IF EXIST GOSALESRT_VIEWS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESRT VIEWS (see log file GOSALESRT_VIEWS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESCT_VIEWS.SQL db2 -td@ -f GOSALESCT_VIEWS.SQL > "%GOSALES_LOG_DIR%GOSALESCT_VIEWS.LOG"
IF EXIST GOSALESCT_VIEWS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESCT VIEWS (see log file GOSALESCT_VIEWS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESDW_VIEWS.SQL db2 -td@ -f GOSALESDW_VIEWS.SQL > "%GOSALES_LOG_DIR%GOSALESDW_VIEWS.LOG"
IF EXIST GOSALESDW_VIEWS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESDW VIEWS (see log file GOSALESDW_VIEWS.LOG) >> %GOSALES_ERROR_LOG%

REM **************************************
REM * Create grants
REM **************************************
echo Granting permissions
IF EXIST GOSALES_GRANTS.SQL db2 -td@ -f GOSALES_GRANTS.SQL > "%GOSALES_LOG_DIR%GOSALES_GRANTS.LOG"
IF EXIST GOSALES_GRANTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALES GRANTS (see log file GOSALES_GRANTS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESHR_GRANTS.SQL db2 -td@ -f GOSALESHR_GRANTS.SQL > "%GOSALES_LOG_DIR%GOSALESHR_GRANTS.LOG"
IF EXIST GOSALESHR_GRANTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESHR GRANTS (see log file GOSALESHR_GRANTS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESMR_GRANTS.SQL db2 -td@ -f GOSALESMR_GRANTS.SQL > "%GOSALES_LOG_DIR%GOSALESMR_GRANTS.LOG"
IF EXIST GOSALESMR_GRANTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESMR GRANTS (see log file GOSALESMR_GRANTS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESRT_GRANTS.SQL db2 -td@ -f GOSALESRT_GRANTS.SQL > "%GOSALES_LOG_DIR%GOSALESRT_GRANTS.LOG"
IF EXIST GOSALESRT_GRANTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESRT GRANTS (see log file GOSALESRT_GRANTS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESCT_GRANTS.SQL db2 -td@ -f GOSALESCT_GRANTS.SQL > "%GOSALES_LOG_DIR%GOSALESCT_GRANTS.LOG"
IF EXIST GOSALESCT_GRANTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESCT GRANTS (see log file GOSALESCT_GRANTS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESDW_GRANTS.SQL db2 -td@ -f GOSALESDW_GRANTS.SQL > "%GOSALES_LOG_DIR%GOSALESDW_GRANTS.LOG"
IF EXIST GOSALESDW_GRANTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESDW GRANTS (see log file GOSALESDW_GRANTS.LOG) >> %GOSALES_ERROR_LOG%

REM **************************************
REM * Update statistics
REM **************************************
echo Updating statistics
IF EXIST GOSALES_RUNSTATS.SQL db2 -td@ -f GOSALES_RUNSTATS.SQL > "%GOSALES_LOG_DIR%GOSALES_RUNSTATS.LOG"
IF EXIST GOSALES_RUNSTATS.SQL IF ERRORLEVEL 1 echo  ERROR RUNNING GOSALES RUNSTATS (see log file GOSALES_RUNSTATS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESHR_RUNSTATS.SQL db2 -td@ -f GOSALESHR_RUNSTATS.SQL > "%GOSALES_LOG_DIR%GOSALESHR_RUNSTATS.LOG"
IF EXIST GOSALESHR_RUNSTATS.SQL IF ERRORLEVEL 1 echo  ERROR RUNNING GOSALESHR RUNSTATS (see log file GOSALESHR_RUNSTATS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESMR_RUNSTATS.SQL db2 -td@ -f GOSALESMR_RUNSTATS.SQL > "%GOSALES_LOG_DIR%GOSALESMR_RUNSTATS.LOG"
IF EXIST GOSALESMR_RUNSTATS.SQL IF ERRORLEVEL 1 echo  ERROR RUNNING GOSALESMR RUNSTATS (see log file GOSALESMR_RUNSTATS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESRT_RUNSTATS.SQL db2 -td@ -f GOSALESRT_RUNSTATS.SQL > "%GOSALES_LOG_DIR%GOSALESRT_RUNSTATS.LOG"
IF EXIST GOSALESRT_RUNSTATS.SQL IF ERRORLEVEL 1 echo  ERROR RUNNING GOSALESRT RUNSTATS (see log file GOSALESRT_RUNSTATS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESCT_RUNSTATS.SQL db2 -td@ -f GOSALESCT_RUNSTATS.SQL > "%GOSALES_LOG_DIR%GOSALESCT_RUNSTATS.LOG"
IF EXIST GOSALESCT_RUNSTATS.SQL IF ERRORLEVEL 1 echo  ERROR RUNNING GOSALESCT RUNSTATS (see log file GOSALESCT_RUNSTATS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESDW_RUNSTATS.SQL db2 -td@ -f GOSALESDW_RUNSTATS.SQL > "%GOSALES_LOG_DIR%GOSALESDW_RUNSTATS.LOG"
IF EXIST GOSALESDW_RUNSTATS.SQL IF ERRORLEVEL 1 echo  ERROR RUNNING GOSALESDW RUNSTATS (see log file GOSALESDW_RUNSTATS.LOG) >> %GOSALES_ERROR_LOG%


REM **************************************
REM * Validation script
REM **************************************
:VERIFY
echo Verifying row counts
SET ERR_CNT=0

IF EXIST GOSALES_VERIFY.SQL db2 -td@ -xf GOSALES_VERIFY.SQL > "%GOSALES_LOG_DIR%GOSALES_VERIFY.LOG"

For /F "eol= tokens=1,2" %%I IN (%GOSALES_LOG_DIR%GOSALES_VERIFY.LOG) DO IF "%%I" neq "0" IF "%%J" neq "" SET /a ERR_CNT+=1 

IF "%ERR_CNT%" neq "0" GOTO VERIFY_ERROR
echo Table row count validation successful && GOTO ADD_COMMENTS

:VERIFY_ERROR
echo ERROR VERIFYING TABLE ROW COUNTS.  See GOSALES_VERIFY.LOG >> "%GOSALES_ERROR_LOG%"

:ADD_COMMENTS
IF "%GOSALES_ONLY_VERIFY%" == "Y" GOTO CLEANUP
echo Adding table comments
IF EXIST GOSALES_ADD_COMMENTS.SQL db2 -td@ -f GOSALES_ADD_COMMENTS.SQL > "%GOSALES_LOG_DIR%GOSALES_ADD_COMMENTS.LOG"
IF EXIST GOSALES_ADD_COMMENTS.SQL IF ERRORLEVEL 1 echo  ERROR ADDING TABLE COMMENTS (see log file GOSALES_ADD_COMMENTS.LOG) >> %GOSALES_ERROR_LOG%


GOTO CLEANUP


:CREATE_DATABASE_ERROR
echo.
type "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"
echo Error creating database - Quitting (%ERRORLEVEL%)
echo.
GOTO CLEANUP

:CREATE_TABLESPACE_ERROR
echo.
type "%GOSALES_LOG_DIR%GOSALES_CREATE_TS.LOG"
echo Error creating bufferpool and tablespace - Quitting (%ERRORLEVEL%)
echo.
GOTO CLEANUP

:CREATE_TABLE_ERROR
echo.
type "%GOSALES_LOG_DIR%GOSALES_TABLES.LOG""
echo Error creating tables - Quitting (%ERRORLEVEL%)
echo.
GOTO CLEANUP

:IMPORT_ERROR
echo.
echo Error loading tables - Quitting (%ERRORLEVEL%)
echo.
GOTO CLEANUP

:CONNECT_ERROR
echo.
echo Error connecting to database %GOSALES_INST% - Quitting (%ERRORLEVEL%)
echo.
GOTO:EOF

:CLEANUP
db2 CONNECT RESET > NUL
db2 TERMINATE > NUL

