@echo OFF
REM *******************************************************************
REM *  5724-E34
REM *  (c) Copyright IBM Corporation 2008, 2009.
REM *  All rights reserved.
REM *
REM *  The source code for this program is not published or otherwise
REM *  divested of its trade secrets, irrespective of what has been
REM *  deposited with the U.S. Copyright Office.
REM *******************************************************************
REM *
REM ******************************************************************
REM *  File: GOSALES_RUN_SCRIPTS.bat
REM *
REM *  Description:
REM *     This script must be started from the setupGSDB.bat
REM *     script.
REM *     This file performs one or more of the following functions :
REM *       - Connects to the subsystem
REM *       - Creates the database and tablespaces
REM *       - Executes the SQL scripts that were generated in the
REM *         RUN_GOSALES_IMPORT.bat file to create the tables, indexes,
REM *         foreign keys, views, privileges and stored procedures that
REM *         make up the GOSALES database
REM *
REM ******************************************************************
SETLOCAL
echo.
REM ************************************************************************
REM * Verify that the script was called correctly
REM ************************************************************************
IF "%GOSALES_START%"=="1" GOTO CONTINUE_RUN
echo THIS SCRIPT MUST BE CALLED FROM "setupGSDB.bat" - QUITTING
GOTO :EOF
:CONTINUE_RUN

IF "%GOSALES_ONLY_VERIFY%"=="Y" GOTO CONNECT_DB
IF "%GOSALES_ONLY_COMMENTS%"=="Y" GOTO CONNECT_DB

REM ******************************************************************
REM * Create the database
REM ******************************************************************
echo Starting GOSALES_RUN_SCRIPTS

db2 connect reset 1>NUL 2>NUL

REM **************************************
REM * Connect to the subsystem
REM **************************************
:CONNECT_DB

echo Connecting to %GOSALES_INST%
db2 connect reset > NUL
db2 terminate > NUL

IF "%GOSALES_ADMIN_USERNAME%" == ""  set /P GOSALES_ADMIN_USERNAME=MISSING VALUE: Enter a value for the DB2 administrator username:
IF "%GOSALES_ADMIN_USERNAME%" == "" GOTO QUITTING_MISSING_ADMIN

IF "%GOSALES_ADMIN_PASSWORD%" neq "" goto CONNECT_WITH_PASSWORD
db2 connect to %GOSALES_INST% user %GOSALES_ADMIN_USERNAME%
IF ERRORLEVEL 1 GOTO CONNECT_ERROR
goto CREATE_DB

:CONNECT_WITH_PASSWORD
  db2 connect to %GOSALES_INST% user %GOSALES_ADMIN_USERNAME% using %GOSALES_ADMIN_PASSWORD%
  IF ERRORLEVEL 1 GOTO CONNECT_ERROR
  REM goto CREATE_DB


:CREATE_DB
IF "%GOSALES_ONLY_VERIFY%"=="Y" GOTO VERIFY
IF "%GOSALES_ONLY_COMMENTS%" == "Y" GOTO ADD_COMMENTS

if /I "%GOSALES_CREATEDB%" neq "Y" goto CREATE_TABLESPACE
  if NOT EXIST GOSALES_CREATE_DB.SQL goto CREATE_TABLESPACE
   echo Create database started at %time% > "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"

   REM ******************************************************************
   REM * Drop the existing database in the shell since we dont worry
   REM * about the error of the result
   REM ******************************************************************
   echo Dropping existing database
   db2 drop database %GOSALES_DB% >> "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"

   REM ******************************************************************
   REM * Run the script to create the database
   REM ******************************************************************
   echo Creating database %GOSALES_DB%
   db2 -td@ -vf GOSALES_CREATE_DB.SQL >> "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"

   IF ERRORLEVEL 1 goto CREATE_DATABASE_ERROR

   echo Create database completed at %time% >> "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"


:CREATE_TABLESPACE


REM **************************************
REM * Create the tablespaces
REM * Skip if not required
REM **************************************
IF /I "%GOSALES_CREATE_BP_AND_TS%" == "N" GOTO CLEAN_DATABASE
echo Creating tablespaces.
db2 -td@ -vf GOSALES_CREATE_TS.SQL > "%GOSALES_LOG_DIR%GOSALES_CREATE_TS.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLESPACE_ERROR

:CLEAN_DATABASE
REM **************************************
REM * Drop existing tables, views and procedures if the option is requested
REM **************************************
IF "%GOSALES_CREATEDB%"=="Y" goto CREATE_TABLES
IF "%GOSALES_CLEAN%"=="N" goto CREATE_TABLES
echo Dropping existing tables
IF EXIST GOSALES_DROP.SQL db2 -td@ -vf GOSALES_DROP.SQL > "%GOSALES_LOG_DIR%GOSALES_DROP.LOG"
IF EXIST GOSALES_DROP.SQL IF ERRORLEVEL 1 echo Error dropping existing tables


:CREATE_TABLES
REM **************************************
REM * Create the tables
REM **************************************
echo Creating tables.
IF EXIST GOSALES_TABLES.SQL db2 -td@ -vf GOSALES_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALES_TABLES.LOG"
REM Check for errors
REM IF EXIST %GOSALES_LOG_DIR%*_SP.LOG for /f %%a IN ('DIR /-W /B %GOSALES_LOG_DIR%*_SP.LOG') do CALL GOSALES_CHECK_LOG.bat "%GOSALES_LOG_DIR%%%a" "ERROR CREATING STORED PROCEDURES" "%GOSALES_ERROR_LOG%" %%a

IF ERRORLEVEL 1 GOTO CREATE_TABLE_ERROR
IF EXIST GOSALESHR_TABLES.SQL db2 -td@ -vf GOSALESHR_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESHR_TABLES.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLE_ERROR
IF EXIST GOSALESMR_TABLES.SQL db2 -td@ -vf GOSALESMR_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESMR_TABLES.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLE_ERROR
IF EXIST GOSALESRT_TABLES.SQL db2 -td@ -vf GOSALESRT_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESRT_TABLES.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLE_ERROR
IF EXIST GOSALESCT_TABLES.SQL db2 -td@ -vf GOSALESCT_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESCT_TABLES.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLE_ERROR
IF EXIST GOSALESDW_TABLES.SQL db2 -td@ -vf GOSALESDW_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESDW_TABLES.LOG"
IF ERRORLEVEL 1 GOTO CREATE_TABLE_ERROR

:CREATE_LOB_TABLES
REM **************************************
REM * Create the auxiliary tables for LOBS
REM **************************************
echo Creating auxiliary tables.
REM IF EXIST GOSALES_LOB_TABLES.SQL db2 -td@ -vf GOSALES_LOB_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALES_LOB_TABLES.LOG"
REM IF ERRORLEVEL 1 GOTO CREATE_LOB_TABLE_ERROR
REM IF EXIST GOSALESHR_LOB_TABLES.SQL db2 -td@ -vf GOSALESHR_LOB_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESHR_LOB_TABLES.LOG"
REM IF ERRORLEVEL 1 GOTO CREATE_LOB_TABLE_ERROR
REM IF EXIST GOSALESMR_LOB_TABLES.SQL db2 -td@ -vf GOSALESMR_LOB_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESMR_LOB_TABLES.LOG"
REM IF ERRORLEVEL 1 GOTO CREATE_LOB_TABLE_ERROR
REM IF EXIST GOSALESRT_LOB_TABLES.SQL db2 -td@ -vf GOSALESRT_LOB_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESRT_LOB_TABLES.LOG"
REM IF ERRORLEVEL 1 GOTO CREATE_LOB_TABLE_ERROR
IF EXIST GOSALESCT_LOB_TABLES.SQL db2 -td@ -vf GOSALESCT_LOB_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESCT_LOB_TABLES.LOG"
IF ERRORLEVEL 1 GOTO CREATE_LOB_TABLE_ERROR
REM IF EXIST GOSALESDW_LOB_TABLES.SQL db2 -td@ -vf GOSALESDW_LOB_TABLES.SQL > "%GOSALES_LOG_DIR%GOSALESDW_LOB_TABLES.LOG"
REM IF ERRORLEVEL 1 GOTO CREATE_LOB_TABLE_ERROR

REM **************************************
REM * Load the data
REM **************************************
IF "%GOSALES_SKIP_IMPORT%"=="Y" goto SKIP

:LOAD
echo starting load at %time% > "%GOSALES_LOG_DIR%GOSALES_LOAD.LOG"
echo Loading data.
db2 -td@ -vf GOSALES_LOAD.SQL >> "%GOSALES_LOG_DIR%GOSALES_LOAD.LOG"
if "%GOSALES_LEVEL%" neq "8" GOTO SKIP
db2 -td@ -vf GOSALESCT_PTNR_ACTIVITY.SQL >> "%GOSALES_LOG_DIR%GOSALES_LOAD.LOG"

IF ERRORLEVEL 1 GOTO IMPORT_ERROR

echo ending load at %time% >> "%GOSALES_LOG_DIR%GOSALES_LOAD.LOG"

:SKIP

REM **************************************
REM * Create indexes
REM **************************************
echo Creating indexes
IF EXIST GOSALES_INDEXES.SQL db2 -td@ -vf GOSALES_INDEXES.SQL > "%GOSALES_LOG_DIR%GOSALES_INDEXES.LOG"
IF EXIST GOSALES_INDEXES.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALES INDEXES (see log file GOSALES_INDEXES.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESHR_INDEXES.SQL db2 -td@ -vf GOSALESHR_INDEXES.SQL > "%GOSALES_LOG_DIR%GOSALESHR_INDEXES.LOG"
IF EXIST GOSALESHR_INDEXES.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESHR INDEXES (see log file GOSALESHR_INDEXES.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESMR_INDEXES.SQL db2 -td@ -vf GOSALESMR_INDEXES.SQL > "%GOSALES_LOG_DIR%GOSALESMR_INDEXES.LOG"
IF EXIST GOSALESMR_INDEXES.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESMR INDEXES (see log file GOSALESMR_INDEXES.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESRT_INDEXES.SQL db2 -td@ -vf GOSALESRT_INDEXES.SQL > "%GOSALES_LOG_DIR%GOSALESRT_INDEXES.LOG"
IF EXIST GOSALESRT_INDEXES.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESRT INDEXES (see log file GOSALESRT_INDEXES.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESCT_INDEXES.SQL db2 -td@ -vf GOSALESCT_INDEXES.SQL > "%GOSALES_LOG_DIR%GOSALESCT_INDEXES.LOG"
IF EXIST GOSALESCT_INDEXES.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESCT INDEXES (see log file GOSALESCT_INDEXES.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESDW_INDEXES.SQL db2 -td@ -vf GOSALESDW_INDEXES.SQL > "%GOSALES_LOG_DIR%GOSALESDW_INDEXES.LOG"
IF EXIST GOSALESDW_INDEXES.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESDW INDEXES (see log file GOSALESDW_INDEXES.LOG) >> %GOSALES_ERROR_LOG%


REM **************************************
REM * Create primary keys
REM **************************************
echo Creating primary keys
IF EXIST GOSALES_PK.SQL db2 -td@ -vf GOSALES_PK.SQL > "%GOSALES_LOG_DIR%GOSALES_PK.LOG"
IF EXIST GOSALES_PK.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALES PRIMARY KEYS (see log file GOSALES_PK.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESHR_PK.SQL db2 -td@ -vf GOSALESHR_PK.SQL > "%GOSALES_LOG_DIR%GOSALESHR_PK.LOG"
IF EXIST GOSALESHR_PK.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESHR PRIMARY KEYS (see log file GOSALESHR_PK.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESMR_PK.SQL db2 -td@ -vf GOSALESMR_PK.SQL > "%GOSALES_LOG_DIR%GOSALESMR_PK.LOG"
IF EXIST GOSALESMR_PK.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESMR PRIMARY KEYS (see log file GOSALESMR_PK.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESRT_PK.SQL db2 -td@ -vf GOSALESRT_PK.SQL > "%GOSALES_LOG_DIR%GOSALESRT_PK.LOG"
IF EXIST GOSALESRT_PK.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESRT PRIMARY KEYS (see log file GOSALESRT_PK.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESCT_PK.SQL db2 -td@ -vf GOSALESCT_PK.SQL > "%GOSALES_LOG_DIR%GOSALESCT_PK.LOG"
IF EXIST GOSALESCT_PK.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESCT PRIMARY KEYS (see log file GOSALESCT_PK.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESDW_PK.SQL db2 -td@ -vf GOSALESDW_PK.SQL > "%GOSALES_LOG_DIR%GOSALESDW_PK.LOG"
IF EXIST GOSALESDW_PK.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESDW PRIMARY KEYS (see log file GOSALESDW_PK.LOG)  >> %GOSALES_ERROR_LOG%


REM **************************************
REM * Create constraints
REM **************************************
echo Creating constraints.
IF EXIST GOSALES_CONSTRAINTS.SQL db2 -td@ -vf GOSALES_CONSTRAINTS.SQL > "%GOSALES_LOG_DIR%GOSALES_CONSTRAINTS.LOG"
IF EXIST GOSALES_CONSTRAINTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALES CONSTRAINTS (see log file GOSALES_CONSTRAINTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESHR_CONSTRAINTS.SQL db2 -td@ -vf GOSALESHR_CONSTRAINTS.SQL > "%GOSALES_LOG_DIR%GOSALESHR_CONSTRAINTS.LOG"
IF EXIST GOSALESHR_CONSTRAINTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESHR CONSTRAINTS (see log file GOSALESHR_CONSTRAINTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESMR_CONSTRAINTS.SQL db2 -td@ -vf GOSALESMR_CONSTRAINTS.SQL > "%GOSALES_LOG_DIR%GOSALESMR_CONSTRAINTS.LOG"
IF EXIST GOSALESMR_CONSTRAINTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESMR CONSTRAINTS (see log file GOSALESMR_CONSTRAINTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESRT_CONSTRAINTS.SQL db2 -td@ -vf GOSALESRT_CONSTRAINTS.SQL > "%GOSALES_LOG_DIR%GOSALESRT_CONSTRAINTS.LOG"
IF EXIST GOSALESRT_CONSTRAINTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESRT CONSTRAINTS (see log file GOSALESRT_CONSTRAINTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESCT_CONSTRAINTS.SQL db2 -td@ -vf GOSALESCT_CONSTRAINTS.SQL > "%GOSALES_LOG_DIR%GOSALESCT_CONSTRAINTS.LOG"
IF EXIST GOSALESCT_CONSTRAINTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESCT CONSTRAINTS (see log file GOSALESCT_CONSTRAINTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESDW_CONSTRAINTS.SQL db2 -td@ -vf GOSALESDW_CONSTRAINTS.SQL > "%GOSALES_LOG_DIR%GOSALESDW_CONSTRAINTS.LOG"
IF EXIST GOSALESDW_CONSTRAINTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESDW CONSTRAINTS (see log file GOSALESDW_CONSTRAINTS.LOG)  >> %GOSALES_ERROR_LOG%

:CREATE_VIEWS
REM **************************************
REM * Create views
REM **************************************
echo Creating views
IF EXIST GOSALES_VIEWS.SQL db2 -td@ -vf GOSALES_VIEWS.SQL > "%GOSALES_LOG_DIR%GOSALES_VIEWS.LOG"
IF EXIST GOSALES_VIEWS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALES VIEWS (see log file GOSALES_VIEWS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESHR_VIEWS.SQL db2 -td@ -vf GOSALESHR_VIEWS.SQL > "%GOSALES_LOG_DIR%GOSALESHR_VIEWS.LOG"
IF EXIST GOSALESHR_VIEWS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESHR VIEWS (see log file GOSALESHR_VIEWS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESMR_VIEWS.SQL db2 -td@ -vf GOSALESMR_VIEWS.SQL > "%GOSALES_LOG_DIR%GOSALESMR_VIEWS.LOG"
IF EXIST GOSALESMR_VIEWS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESMR VIEWS (see log file GOSALESMR_VIEWS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESRT_VIEWS.SQL db2 -td@ -vf GOSALESRT_VIEWS.SQL > "%GOSALES_LOG_DIR%GOSALESRT_VIEWS.LOG"
IF EXIST GOSALESRT_VIEWS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESRT VIEWS (see log file GOSALESRT_VIEWS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESCT_VIEWS.SQL db2 -td@ -vf GOSALESCT_VIEWS.SQL > "%GOSALES_LOG_DIR%GOSALESCT_VIEWS.LOG"
IF EXIST GOSALESCT_VIEWS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESCT VIEWS (see log file GOSALESCT_VIEWS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESDW_VIEWS.SQL db2 -td@ -vf GOSALESDW_VIEWS.SQL > "%GOSALES_LOG_DIR%GOSALESDW_VIEWS.LOG"
IF EXIST GOSALESDW_VIEWS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESDW VIEWS (see log file GOSALESDW_VIEWS.LOG) >> %GOSALES_ERROR_LOG%

REM **************************************
REM * Create grants
REM **************************************
echo Granting permissions
IF EXIST GOSALES_GRANTS.SQL db2 -td@ -vf GOSALES_GRANTS.SQL > "%GOSALES_LOG_DIR%GOSALES_GRANTS.LOG"
IF EXIST GOSALES_GRANTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALES GRANTS (see log file GOSALES_GRANTS.LOG) >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESHR_GRANTS.SQL db2 -td@ -vf GOSALESHR_GRANTS.SQL > "%GOSALES_LOG_DIR%GOSALESHR_GRANTS.LOG"
IF EXIST GOSALESHR_GRANTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESHR GRANTS (see log file GOSALESHR_GRANTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESMR_GRANTS.SQL db2 -td@ -vf GOSALESMR_GRANTS.SQL > "%GOSALES_LOG_DIR%GOSALESMR_GRANTS.LOG"
IF EXIST GOSALESMR_GRANTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESMR GRANTS (see log file GOSALESMR_GRANTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESRT_GRANTS.SQL db2 -td@ -vf GOSALESRT_GRANTS.SQL > "%GOSALES_LOG_DIR%GOSALESRT_GRANTS.LOG"
IF EXIST GOSALESRT_GRANTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESRT GRANTS (see log file GOSALESRT_GRANTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESCT_GRANTS.SQL db2 -td@ -vf GOSALESCT_GRANTS.SQL > "%GOSALES_LOG_DIR%GOSALESCT_GRANTS.LOG"
IF EXIST GOSALESCT_GRANTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESCT GRANTS (see log file GOSALESCT_GRANTS.LOG)  >> %GOSALES_ERROR_LOG%
IF EXIST GOSALESDW_GRANTS.SQL db2 -td@ -vf GOSALESDW_GRANTS.SQL > "%GOSALES_LOG_DIR%GOSALESDW_GRANTS.LOG"
IF EXIST GOSALESDW_GRANTS.SQL IF ERRORLEVEL 1 echo  ERROR CREATING GOSALESDW GRANTS (see log file GOSALESDW_GRANTS.LOG)  >> %GOSALES_ERROR_LOG%

REM **************************************
REM * Validation script
REM **************************************
:VERIFY
echo Verifying row counts
SET ERR_CNT=0

IF EXIST GOSALES_VERIFY.SQL db2 -td@ -xf GOSALES_VERIFY.SQL > "%GOSALES_LOG_DIR%GOSALES_VERIFY.LOG"

For /F "eol= tokens=1,2" %%I IN (%GOSALES_LOG_DIR%GOSALES_VERIFY.LOG) DO IF "%%I" neq "0" IF "%%J" neq "" SET /a ERR_CNT+=1 

IF "%ERR_CNT%" neq "0" GOTO VERIFY_ERROR
echo Table row count validation successful && GOTO ADD_COMMENTS
GOTO CLEANUP

:VERIFY_ERROR
echo ERROR VERIFYING TABLE ROW COUNTS. (see log file GOSALES_VERIFY.LOG) >> "%GOSALES_ERROR_LOG%"

:ADD_COMMENTS
IF "%GOSALES_ONLY_VERIFY%"=="Y" GOTO CLEANUP
echo Adding table comments
IF EXIST GOSALES_ADD_COMMENTS.SQL db2 -td@ -f GOSALES_ADD_COMMENTS.SQL > "%GOSALES_LOG_DIR%GOSALES_ADD_COMMENTS.LOG"
IF EXIST GOSALES_ADD_COMMENTS.SQL IF ERRORLEVEL 1 echo  ERROR ADDING TABLE COMMENTS (see log file GOSALES_ADD_COMMENTS.LOG)  >> %GOSALES_ERROR_LOG%

GOTO CLEANUP

:CREATE_DATABASE_ERROR
echo.
type "%GOSALES_LOG_DIR%GOSALES_CREATE_DB.LOG"
echo Error creating database - Quitting (%ERRORLEVEL%)
echo.
GOTO CLEANUP

:CREATE_TABLESPACE_ERROR
echo.
type "%GOSALES_LOG_DIR%GOSALES_CREATE_TS.LOG"
echo Error creating bufferpool and tablespace - Quitting (%ERRORLEVEL%)
echo.
GOTO CLEANUP

:CREATE_TABLE_ERROR
echo.
type "%GOSALES_LOG_DIR%GOSALES_TABLES.LOG""
echo Error creating tables - Quitting (%ERRORLEVEL%)
echo.
GOTO CLEANUP

:CREATE_LOB_TABLE_ERROR
echo.
type "%GOSALES_LOG_DIR%GOSALES_LOB_TABLES.LOG""
echo Error creating auxiliary tables - Quitting (%ERRORLEVEL%)
echo.
GOTO CLEANUP

:IMPORT_ERROR
echo.
echo Error loading tables - Quitting (%ERRORLEVEL%)
echo.
GOTO CLEANUP

:QUITTING_MISSING_ADMIN
echo.
echo No admin username provided - Quitting (%ERRORLEVEL%)
echo.
GOTO CLEANUP

:CONNECT_ERROR
echo.
echo Error connecting to subsystem %GOSALES_INST% - Quitting (%ERRORLEVEL%)
echo.
GOTO:EOF

:CLEANUP
db2 CONNECT RESET > NUL
db2 TERMINATE > NUL

